The application exposes the `com.facebook.react.devsupport.DevSettingsActivity` activity. The  `DevSettingsActivity` Activity exposes developer settings and should not pas exposed in release versions of the application.

